/* CSD: Cornerstone disassembler

    Copyright (C) 2014  John Elliott <jce@seasip.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

package info.seasip.csd;
import java.io.*;

/** Represents the initial RAM image. Loaded from the MME file.
 *
 * @author      John Elliott <jce@seasip.demon.co.uk>
 * @version     1.0
 * @since       2014-04-12
 */
public class Ram 
{
	RandomAccessFile file;
	int size;
	byte [] data;	
	long base;

	Ram(RandomAccessFile rf, int size)
	{
		file = rf;
		data = new byte[size];
	}

	public byte peek(int addr)
	{
		addr &= 0xFFFF;
		if (addr < data.length) return data[addr];
		return 0;
	}
	
	public int peekw(int addr)
	{
		addr &= 0xFFFF;
		if (addr >= data.length) return 0;
		int l = data[addr++];
		if (addr >= data.length) return l & 0xFF;
		int h = data[addr];
		return ((h << 8) | l) & 0xFFFF;
	}

	public void load() throws IOException
	{
		base = file.getFilePointer();
		file.read(data);	
	}


	public void showContents(PrintStream stream)
	{
		stream.println(";---------------------------------------");
		stream.println("; MME RAM image:");
		stream.println(";---------------------------------------");

		for (int n = 0; n < data.length; n += 16)
		{
			int m;

			stream.printf("; %04x: ", n);

			for (m = 0; m < 16; m++)
			{
				if (n + m >= data.length)
					stream.print("   ");
				else	stream.printf("%02x ", data[n+m] & 0xFF);
			}			
			stream.print("   ");
			for (m = 0; m < 16; m++)
			{
				char c;

				if (n + m >= data.length)
					c = 0;
				else	c = (char)data[n+m];

				if (c < ' ' || c > '~') c = '.';
				stream.print(c);	
			}			
			stream.print("\n");
		}

	}

}

