/* CSD: Cornerstone disassembler

    Copyright (C) 2014  John Elliott <jce@seasip.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

package info.seasip.csd;
import java.io.*;

/** Base class for an object that's stored on disk as an array of 16-bit
 * little-endian words. 
 *
 * The Cornerstone headers are all stored in this form, so this is the base
 * class for them all.
 *
 * @author      John Elliott <jce@seasip.demon.co.uk>
 * @version     1.0
 * @since       2014-04-12
 */
class WordChunk
{
	/** The file we load data from. */
	protected RandomAccessFile file;
	/** The array the words are loaded into. */
	protected int words[];

	/** Constructor.
	 *
	 * @param rf The file from which data will be loaded.
	 */
	WordChunk(RandomAccessFile rf)
	{
		file = rf;
	}

	/** Read a single word from the file.
	 *
	 * @return The two bytes at the file's current position, treated as
	 * 	   a little-endian word.
	 * @exception IOException In the event of a read error.
	 */
	int read() throws IOException
	{
		int l = file.readUnsignedByte();
		int h = file.readUnsignedByte();

		return (h << 8) | l;
	}

	/** Read a number of words from the file. The words[] member will
	 *  be populated with the result.
	 *
	 * @param count The number of words to read.
	 * @exception IOException In the event of a read error.
	 */
	void read(int count) throws IOException
	{
		int n;

		words = new int[count];
		for (n = 0; n < count; n++) words[n] = read();
	}



}

